@@ -5,16 +5,25 @@ import ast
 from pprint import pformat
 
 
+class NotReverseEvaluable(Exception):
+    pass
+
+
+def raise_if_NotReverseEvaluable(data, stringed_data):
+    try:
+        ast.literal_eval(stringed_data)
+    except Exception as e:
+        raise NotReverseEvaluable(
+            f"pprint.pformat({type(data)}) is bad for ast.literal_eval()")
+
+
 def dump(filename, data):
     """
     with codecs.open(filename, 'w', 'utf-8') as f:
         f.write(pformat(data))
     """
     stringed_data = pformat(data)
-    try:
-        ast.literal_eval(stringed_data)
-    except Exception as e:
-        raise Exception("given data is not evaluable by ast.literal_eval")
+    raise_if_NotReverseEvaluable(data, stringed_data)
     with codecs.open(filename, 'w', 'utf-8') as f:
         f.write(stringed_data)
 
